@@ -22,6 +22,8 @@ SEXP R_zmq_connect(SEXP R_socket, SEXP R_endpoint);
 SEXP R_zmq_disconnect(SEXP R_socket, SEXP R_endpoint);
 SEXP R_zmq_setsockopt(SEXP R_socket, SEXP R_option_name, SEXP R_option_value,
 	SEXP R_option_type);
+SEXP R_zmq_getsockopt(SEXP R_socket, SEXP R_option_name, SEXP R_option_value,
+	SEXP R_option_type);
 
 /* Message related. */
 // static void msg_Finalizer(SEXP R_msg_t);
@@ -46,4 +48,10 @@ SEXP R_zmq_version();
 /* shellexec. */
 SEXP shellexec_wcc(SEXP R_file, SEXP R_SW_cmd);
 
+/* Poll related. */
+SEXP R_zmq_poll(SEXP R_socket, SEXP R_type, SEXP R_timeout);
+SEXP R_zmq_poll_free();
+SEXP R_zmq_poll_length();
+SEXP R_zmq_poll_get_revents(SEXP R_index);
+
 #endif
