@@ -2,22 +2,7 @@
 
 
 /* Context related. */
-/* Use R level reg.finalizer to handle this and avoid seg. fault.
-static void ctx_Finalizer(SEXP R_context){
-	int C_ret = -1, C_errno;
-	void *C_context = R_ExternalPtrAddr(R_context);
-
-	if(C_context != NULL){
-		C_ret = zmq_ctx_destroy(C_context);
-		// No need to cast error at the end of R.
-		// if(C_ret == -1){
-		// 	C_errno = zmq_errno();
-		// 	REprintf("ctx_Finalizer errno: %d strerror: %s\n",
-		// 		C_errno, zmq_strerror(C_errno));
-		// }
-		R_ClearExternalPtr(R_context);
-	}
-}*/ /* End of ctx_Finalizer(). */
+/* Use R level reg.finalizer to handle this and avoid seg. fault. */
 
 SEXP R_zmq_ctx_new(){
 	SEXP R_context = R_NilValue;
@@ -28,7 +13,7 @@ SEXP R_zmq_ctx_new(){
 		// R_RegisterCFinalizerEx(R_context, ctx_Finalizer, TRUE);
 		UNPROTECT(1);
 	} else{
-		REprintf("R_zmq_ctx_new: R_context is not available.\n");
+		warning("R_zmq_ctx_new: R_context is not available.\n");
 	}
 	return(R_context);
 } /* End of Rzmq_ctx_new(). */
@@ -44,7 +29,7 @@ SEXP R_zmq_ctx_destroy(SEXP R_context){
 	C_ret = zmq_ctx_destroy(C_context);
 	if(C_ret == -1){
 		C_errno = zmq_errno();
-		REprintf("R_zmq_ctx_destroy errno: %d strerror: %s\n",
+		warning("R_zmq_ctx_destroy errno: %d strerror: %s\n",
 			C_errno, zmq_strerror(C_errno));
 	}
 	return(AsInt(C_ret));
